pub struct TypedInterner<T: Internable> { /* private fields */ }
An interner for any type that implements Borrow. Not many optimizations are employed and the interner uses the default allocator. This and the use of weak references means that a long-lived instance can be kept around with regular calls to TypedInterner::sweep.

Implementations

source

impl<T: Internable> TypedInterner<T>

source

pub fn new() -> Arc<Self>

Create a fresh interner instance

source

pub fn size(self: &Arc<Self>) -> usize

Get the number of stored values

source

pub fn sweep(&self) -> usize

Remove entries which are no longer referenced anywhere else

source

pub fn i<Q>(self: &Arc<Self>, q: &Q) -> Tok<T>
where Q: ?Sized + Eq + Hash + ToOwned<Owned = T>, T: Borrow<Q>,

Intern an object, returning a token