Tok

Struct Tok 

pub struct Tok<T: Internable> { /* private fields */ }
A shared instance. Equality comparison costs two pointer comparisons. Ordering is by pointer value.

Panics

If an interner was manually constructed, tokens from different interners cannot be compared and attempting to do so causes a panic.

Since a given Interner uses a single TypedInterner for each type, this is only possible if an Interner or TypedInterner was constructed besides the singleton.

Implementations

Source

impl<T: Internable> Tok<T>

pub fn id(&self) -> NonZeroUsize

The pointer value of the token. If this is equal, equality comparison succeeds.

pub fn interner_id(&self) -> NonZeroUsize

The pointer value of the interner. If this is different, comparison panics.

pub fn usize(&self) -> usize

Cast into usize

pub fn assert_comparable(&self, other: &Self)

Panic if the two tokens weren’t created with the same interner

pub fn interner(&self) -> Arc<TypedInterner<T>>

Get the typed interner that owns this token.

pub fn i<Q>(q: &Q) -> Self
where Q: ?Sized + Eq + Hash + ToOwned<Owned = T>, T: Borrow<Q>,

Source

impl<T: Internable> Tok<Vec<Tok<T>>>

pub fn ev(&self) -> Vec<T>

Extern all elements of the vector in a new vector. If the vector itself isn’t interned, use ev

Source

impl<T: Internable> Tok<Vec<Tok<T>>>

pub fn append(&self, suffix: impl IntoIterator<Item = Tok<T>>) -> Self

Add a suffix to the interned vector

pub fn prepend(&self, prefix: impl IntoIterator<Item = Tok<T>>) -> Self

Add a prefix to the interned vector