pub struct Interner { /* private fields */ }
A collection of interners based on their type. Can be used to intern any object that implements ToOwned. Objects of the same type are stored together in a TypedInterner

Implementations

source

impl Interner

source

pub fn new() -> Self

Create a new interner

source

pub fn i<Q>(&self, q: &Q) -> Tok<Q::Owned>
where Q: ?Sized + Eq + Hash + ToOwned, Q::Owned: 'static + Eq + Hash + Clone + Borrow<Q> + Send + Sync,

Intern something

source

pub fn sweep_t<T: Eq + Hash + Clone + Send + Sync + 'static>(&self) -> usize

Sweep values of a specific type. Useful if you just constructed a large number of values of a specific type, otherwise use Interner::sweep

source

pub fn sweep(&self) -> usize

Sweep all values not referenced by anything other than the interner.

source

pub fn iv<T: 'static + Eq + Hash + Clone + Sync + Send>( &self, s: impl IntoIterator<Item = T> ) -> Tok<Vec<Tok<T>>>

Intern a list and its elements. See also Interner::ibv

source

pub fn ibv<'a, Q>( &self, s: impl IntoIterator<Item = &'a Q> ) -> Tok<Vec<Tok<Q::Owned>>>
where Q: ?Sized + Eq + Hash + ToOwned + 'a, Q::Owned: Eq + Hash + Clone + Send + Sync,

Intern a list of borrowed items. See also Interner::iv