Struct intern_all::instance::Interner
source · pub struct Interner { /* private fields */ }Expand description
A collection of interners based on their type. Can be used to intern any object that implements ToOwned. Objects of the same type are stored together in a TypedInterner
Implementations
sourceimpl Interner
impl Interner
sourcepub fn sweep_t<T: Eq + Hash + Clone + Send + Sync + 'static>(&self) -> usize
pub fn sweep_t<T: Eq + Hash + Clone + Send + Sync + 'static>(&self) -> usize
Sweep values of a specific type. Useful if you just constructed a large number of values of a specific type, otherwise use Interner::sweep
sourcepub fn sweep(&self) -> usize
pub fn sweep(&self) -> usize
Sweep all values not referenced by anything other than the interner.