Struct intern_all::instance::TypedInterner
source · pub struct TypedInterner<T: 'static + Eq + Hash + Clone + Send + Sync> { /* private fields */ }Expand description
An interner for any type that implements Borrow. Not many optimizations are employed and the interner uses the default allocator. This and the use of weak references means that a long-lived instance can be kept around with regular calls to TypedInterner::sweep.
Implementations