Struct intern_all::Tok

source ·
pub struct Tok<T: Eq + Hash + Clone + Send + Sync + 'static> { /* private fields */ }
A shared instance. Equality comparison costs two pointer comparisons. Ordering is by pointer value.

Panics

If an interner was manually constructed, tokens from different interners cannot be compared and attempting to do so causes a panic.

Since a given Interner uses a single TypedInterner for each type, this is only possible if an Interner or TypedInterner was constructed besides the singleton.

Implementations

source

impl<T: Eq + Hash + Clone + Send + Sync + 'static> Tok<T>

source

pub fn id(&self) -> NonZeroUsize

The pointer value of the token. If this is equal, equality comparison succeeds.

source

pub fn interner_id(&self) -> NonZeroUsize

The pointer value of the interner. If this is different, comparison panics.

source

pub fn usize(&self) -> usize

Cast into usize

source

pub fn assert_comparable(&self, other: &Self)

Panic if the two tokens weren’t created with the same interner

source

pub fn interner(&self) -> Arc<TypedInterner<T>>

Get the typed interner that owns this token.

source

pub fn i<Q>(q: &Q) -> Self
where Q: ?Sized + Eq + Hash + ToOwned<Owned = T>, T: Borrow<Q>,

source

impl<T: Eq + Hash + Clone + Send + Sync + 'static> Tok<Vec<Tok<T>>>

source

pub fn ev(&self) -> Vec<T>

Extern all elements of the vector in a new vector. If the vector itself isn’t interned, use ev

source

impl<T: Eq + Hash + Clone + Send + Sync + 'static> Tok<Vec<Tok<T>>>

source

pub fn append(&self, suffix: impl IntoIterator<Item = Tok<T>>) -> Self

Add a suffix to the interned vector

source

pub fn prepend(&self, prefix: impl IntoIterator<Item = Tok<T>>) -> Self

Add a prefix to the interned vector