Struct intern_all::Tok
source · pub struct Tok<T: Eq + Hash + Clone + Send + Sync + 'static> { /* private fields */ }Expand description
A shared instance. Equality comparison costs two pointer comparisons. Ordering is by pointer value.
Panics
If an interner was manually constructed, tokens from different interners cannot be compared and attempting to do so causes a panic.
Since a given Interner uses a single TypedInterner for each type, this is only possible if an Interner or TypedInterner was constructed besides the singleton.
Implementations
sourceimpl<T: Eq + Hash + Clone + Send + Sync + 'static> Tok<T>
impl<T: Eq + Hash + Clone + Send + Sync + 'static> Tok<T>
sourcepub fn id(&self) -> NonZeroUsize
pub fn id(&self) -> NonZeroUsize
The pointer value of the token. If this is equal, equality comparison succeeds.
sourcepub fn interner_id(&self) -> NonZeroUsize
pub fn interner_id(&self) -> NonZeroUsize
The pointer value of the interner. If this is different, comparison panics.
sourcepub fn assert_comparable(&self, other: &Self)
pub fn assert_comparable(&self, other: &Self)
Panic if the two tokens weren’t created with the same interner
sourcepub fn interner(&self) -> Arc<TypedInterner<T>>
pub fn interner(&self) -> Arc<TypedInterner<T>>
Get the typed interner that owns this token.
pub fn i<Q>(q: &Q) -> Self